package org.eclipse.cosmos.rm.validation.internal.databuilders;

import java.util.Map;

import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import junit.framework.Test;

import org.eclipse.cosmos.rm.validation.internal.artifacts.DocumentNode;
import org.eclipse.cosmos.rm.validation.internal.artifacts.ElementEdge;
import org.eclipse.cosmos.rm.validation.internal.databuilders.ReferenceGraphDataBuilder;
import org.eclipse.hyades.test.common.junit.DefaultTestArbiter;
import org.eclipse.hyades.test.common.junit.HyadesTestCase;
import org.eclipse.hyades.test.common.junit.HyadesTestSuite;

/**
 * Generated code for the test suite <b>TestReferenceGraphGenerator</b> located at
 * <i>/org.eclipse.cosmos.rm.validation.tests/junits/TestReferenceGraphGenerator.testsuite</i>.
 */
public class TestReferenceGraphGenerator extends HyadesTestCase
{
	/**
	 * Constructor for TestReferenceGraphGenerator.
	 * @param name
	 */
	public TestReferenceGraphGenerator(String name)
	{
		super(name);
	}

	/**
	 * Returns the JUnit test suite that implements the <b>TestReferenceGraphGenerator</b> definition.
	 */
	public static Test suite()
	{
		HyadesTestSuite testReferenceGraphGenerator = new HyadesTestSuite("TestReferenceGraphGenerator");
		testReferenceGraphGenerator.setArbiter(DefaultTestArbiter.INSTANCE).setId("E591F6CBDF3B324E08326FD079BB11DB");
		testReferenceGraphGenerator.addTest(new TestReferenceGraphGenerator("testRefGraphGeneration").setId("E591F6CBDF3B324E0B6698C079BB11DB").setTestInvocationId("E591F6CBDF3B324E0B8D7C107A4711DB"));
		return testReferenceGraphGenerator;
	}

	/**
	 * @see junit.framework.TestCase#setUp()
	 */
	protected void setUp() throws Exception
	{
	}

	/**
	 * @see junit.framework.TestCase#tearDown()
	 */
	protected void tearDown() throws Exception
	{
	}

	/**
	 * testRefGraphGeneration
	 * @throws Exception
	 */
	public void testRefGraphGeneration() throws Exception
	{
		final String[] COURSE_ALIASES = new String[]{"Course1", "Course2", "Course3"};
		final String[] SOURCE_ELEMENTS = new String[]{"RequiredPreRequisite", "OptionalPreRequisite", "OptionalPreRequisite"};
		final String[] REFERENCE = new String[]{"Course2", "Course3", "Course1"};
		final String INVALID_CYCLE_FILE = "test-resources/invalid-cycle.xml";
		
		ReferenceGraphDataBuilder refGraphGeneration = new ReferenceGraphDataBuilder();
		SAXParser saxParser = SAXParserFactory.newInstance().newSAXParser();
		saxParser.parse(this.getClass().getClassLoader().getResourceAsStream(INVALID_CYCLE_FILE), refGraphGeneration);
		
		Map referenceGraph = (Map)refGraphGeneration.getDataStructure();
		
		assertNotNull("The data structure is null", referenceGraph);
		for (int i = 0; i < COURSE_ALIASES.length; i++)
		{
			DocumentNode courseNode = (DocumentNode)referenceGraph.get(COURSE_ALIASES[i]);
			assertNotNull("Course with alias: " + COURSE_ALIASES[i] + " was not found", courseNode);
			
			ElementEdge[] elementEdges = courseNode.getEdges();
			assertEquals("Course: " + COURSE_ALIASES[i] + " expected to only have one edge", 1, elementEdges.length);
			assertEquals("The expected source element is invalid", SOURCE_ELEMENTS[i], elementEdges[0].getSourceElement());
			assertEquals("The expected reference is invalid", REFERENCE[i], elementEdges[0].getReference());
		}
	}

}
