/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.artifacts;

import java.util.ArrayList;
import java.util.List;

/**
 * A document node is used to represent an SML-IF document 
 * 
 * @author Ali Mehregani
 */
public class DocumentNode
{
	/**
	 * The aliases of this document
	 */
	private List aliases;
	
	/**
	 * The edges of this document node
	 */
	private List edges;
	
	
	/**
	 * Returns the aliases of this document
	 * 
	 * @return The aliases of this document node
	 */
	public String[] getAliases()
	{
		if (aliases == null)
			return null;
		
		return (String[])aliases.toArray(new String[aliases.size()]);
	}

	
	/**
	 * Add an alias for this document node.  An alias is used to reference
	 * a document.
	 * 
	 * @param alias The alias to be added
	 */
	public void addAlias(String alias)
	{
		if (aliases == null)
			aliases = new ArrayList();
		
		aliases.add(alias);
	}
	
	
	/**
	 * Adds an element edge to this document
	 * 
	 * @param edge The element edge
	 */
	public void addEdge(ElementEdge edge)
	{
		if (edges == null)
			edges = new ArrayList();
		
		edges.add(edge);
	}
	
	
	/**
	 * Retrieves the element edges of this document node
	 * 
	 * @return The element edges
	 */
	public ElementEdge[] getEdges()
	{
		if (edges == null)
			return null;
		return (ElementEdge[])edges.toArray(new ElementEdge[edges.size()]);
	}


	public ElementEdge[] getEdges(String elementName)
	{
		// TODO Auto-generated method stub
		return null;
	}

}
