/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.artifacts;

/**
 * An element edge represents an edge from a target to a source
 * element from/in the contained document
 * 
 * @author Ali Mehregani
 */
public class ElementEdge
{
	/**
	 * The reference string that will be used to resolve the target 
	 * document and element.
	 */
	private String reference;

	/**
	 * The source element
	 */
	private String sourceElement;
	
	
	/**
	 * Constructor
	 */
	public ElementEdge()
	{
		reference = "";
	}
	
	
	/**
	 * Set the source element
	 * 
	 * @param sourceElement The source element
	 */
	public void setSourceElement(String sourceElement)
	{
		this.sourceElement = sourceElement;
	}

	
	/**
	 * Returns the source element
	 * 
	 * @return source element
	 */
	public String getSourceElement()
	{
		return sourceElement;
	}
	
	
	/**
	 * Appends to the reference path
	 * 
	 * @param referece the string to be appended to the reference path
	 */
	public void appendToReference(String referece)
	{
		this.reference += referece;		
	}
	
	
	/**
	 * Returns the reference string
	 * 
	 * @return The reference string
	 */
	public String getReference()
	{
		return reference;
	}

	
	/**
	 * Sets the reference string
	 * 
	 * @param reference The reference string
	 */
	public void setReference(String reference)
	{
		this.reference = reference;
	}


	public String getDocument()
	{
		// TODO Auto-generated method stub
		return null;
	}
}
