/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.core;

import java.util.Map;


/**
 * The generic interface that is shared between the different phase of 
 * the validation process.
 * 
 * @see IXMLValidator
 * @see ISMLValidator
 * @see ISchematronValidation
 * @author Ali Mehregani
 */
public interface IValidator
{
	/**
	 * Indicates the validation output attribute
	 */
	public static final String ATTRIBUTE_OUTPUT = "validation.output";
	
	/**
	 * Indicates the  file location of the schema document.  
	 */
	public static final String ATTRIBUTE_SCHEMA = "validation.schema";


	/**
	 * Initialize this validation class based on the set of attributes
	 * passed in.  See the ATTRIBUTE_* available.
	 * 
	 * @param validationAttribute The validation outputs
	 */
	public void intialize(Map validationAttribute);

	
	/**
	 * Performs the validation and returns true if successful and
	 * false otherwise.
	 * 
	 * @return true if successful; false otherwise
	 */
	public boolean validate();

}
