/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.core;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.util.Map;

import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import org.eclipse.cosmos.rm.validation.internal.common.AbstractValidationOutput;

/**
 * This is the Schematron validation implementation class.   
 * @author sleeloy
 *
 */
public class SchematronValidatorImpl implements ISchematronValidation {
	protected String xsd; 
	//currently hard code the location of the style sheet to extract the schematron from the schema file
	protected final static String SKELETON15="schematron\\skeleton1-5.xsl";
    protected AbstractValidationOutput validationLogger;
    protected Source xml;
    
	public void intialize(Map validationAttribute) {
		validationLogger = (AbstractValidationOutput)validationAttribute.get(ATTRIBUTE_OUTPUT);
		//get the schema.  Assume that the schema attribute is a file location
		//TODO need to support other source types such as an input stream of uri. 
		xsd = (String)validationAttribute.get(ATTRIBUTE_SCHEMA);
		
	}
	
	/**
	 * TODO: should pass xml instance as an attribute
	 */
	public void setXML(Object xml){
		if (xml instanceof String)
			this.xml = new StreamSource((String)xml);		
	}

	/**
	 * Executes the schematron validation
	 */
	public boolean validate(){
		try {
			StringWriter sw = new StringWriter();
			
			StreamResult schematron = new StreamResult(sw);
			transform(new StreamSource(xsd), new StreamSource(SKELETON15), schematron);
			schematron.getWriter().flush();
			StringReader sr = new StringReader(sw.getBuffer().toString());
			StreamSource schematronSource = new StreamSource(sr);
			
			StringWriter errorStream = new StringWriter();
			
			StreamResult errorStreamResult = new StreamResult(errorStream);
			transform(xml, schematronSource, errorStreamResult);
			parseMessageStream(errorStream.getBuffer().toString());
			return true;
		} catch (IOException e) {
			validationLogger.reportError(e.getLocalizedMessage());
		}
		
		return false;
	}

	/**
	 * Helper method that will apply a xslt transform to a given xml source and write the results
	 * to a Result object
	 * @param source xml source 
	 * @param xslt xslt transform that will be applied to the source
	 * @param result stores the resulting transform
	 */
	protected void transform(Source source, Source xslt, Result result) {
		Transformer transformer = null;

		// Instantiate a TransformerFactory
		TransformerFactory tFactory = TransformerFactory.newInstance();

		// Use the TransformerFactory to process the stylesheet source and
		// generate a Transformer.
		try {
			transformer = tFactory.newTransformer(xslt);

			// Use the Transformer to transform an XML Source and send the
			// output to a Result object.
			transformer.transform(source, result);

		} catch (TransformerConfigurationException e) {
			validationLogger.reportError(e.getLocalizedMessage());
		} catch (TransformerException e) {
			validationLogger.reportError(e.getLocalizedMessage());
		}
	}
	
	/**
	 * Helper method that logs the schematron message
	 * @param messageStream schematron message
	 */
	protected void parseMessageStream(String messageStream){
		validationLogger.reportError(messageStream);
	}

}
