/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.databuilders;

import java.util.Hashtable;
import java.util.Iterator;
import java.util.Map;

import org.eclipse.cosmos.rm.validation.internal.SMLActivator;
import org.eclipse.cosmos.rm.validation.internal.common.ISMLConstants;
import org.eclipse.cosmos.rm.validation.internal.common.IValidationConstants;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * This data structure stores a list of elements that are of type
 * acyclic.
 * 
 * @author Ali Mehregani
 */
public class AcyclicDataTypesList extends DefaultHandler implements IDataBuilder
{
	/**
	 * The ID of this data type builder
	 */
	public static final String ID = SMLActivator.PLUGIN_ID + ".AcyclicDataTypesList";
		
	/**
	 * Stores the acyclic types
	 */
	private Map acyclicTypes;
	
	/**
	 * Constructor
	 */
	public AcyclicDataTypesList()
	{
		acyclicTypes = new Hashtable();
	}
	
	/**
	 * @see org.xml.sax.helpers.DefaultHandler#startElement(java.lang.String, java.lang.String, java.lang.String, org.xml.sax.Attributes)
	 */
	public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException
	{		
		if (attributes == null || 
			!IValidationConstants.TRUE_VALUE.equalsIgnoreCase(attributes.getValue(ISMLConstants.ACYCLIC_ATTRIBUTE)) ||
			acyclicTypes.get(qName) != null)
			return;
		
		String name = attributes.getValue(ISMLConstants.NAME_ATTRIBUTE);
		if (name != null)
			acyclicTypes.put(name, IValidationConstants.TRUE_VALUE);
	}

		
	/**
	 * The data structure returned is of type {@link Iterator}
	 * @see org.eclipse.cosmos.rm.validation.internal.databuilders.IDataBuilder#getDataStructure()
	 */
	public Object getDataStructure()
	{
		return acyclicTypes.keySet().iterator();
	}
}
