/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.smlvalidators;

import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.eclipse.cosmos.rm.validation.internal.common.AbstractValidationOutput;
import org.eclipse.cosmos.rm.validation.internal.core.ISMLValidator;
import org.eclipse.cosmos.rm.validation.internal.databuilders.ComplexTypeElementBuilder;
import org.eclipse.cosmos.rm.validation.internal.databuilders.DataBuilderRegistry;
import org.eclipse.cosmos.rm.validation.internal.databuilders.IDataBuilder;
import org.eclipse.cosmos.rm.validation.internal.databuilders.RefTypeElementBuilder;
import org.eclipse.cosmos.rm.validation.internal.databuilders.TargetElementBuilder;
import org.eclipse.cosmos.rm.validation.internal.databuilders.TypeInheritanceDataBuilderImpl;

public class TargetElementValidatorImpl implements ISMLValidator {
    protected AbstractValidationOutput validationLogger;

	public void intialize(Map validationAttribute) {
		validationLogger = (AbstractValidationOutput)validationAttribute.get(ATTRIBUTE_OUTPUT);
	}

	public boolean validate() {
		IDataBuilder targetElement = DataBuilderRegistry.instance().getDataStructureBuilder(TargetElementBuilder.ID);
		IDataBuilder refTypeElement = DataBuilderRegistry.instance().getDataStructureBuilder(RefTypeElementBuilder.ID);
		IDataBuilder typeInheritance = DataBuilderRegistry.instance().getDataStructureBuilder(TypeInheritanceDataBuilderImpl.ID);
		IDataBuilder complexTypeElement = DataBuilderRegistry.instance().getDataStructureBuilder(ComplexTypeElementBuilder.ID);
		
		Map targetElems = (Map)targetElement.getDataStructure();
		List refTypeElems = (List)refTypeElement.getDataStructure();
		List complexTypeElems = (List)complexTypeElement.getDataStructure();
		Map inheritance = (Map)typeInheritance.getDataStructure();
		
		//The sml:targetElement attribute is supported on element 
		//declarations whose type is sml:refType or a derived type
		//of sml:refType. 
		Iterator iter = targetElems.keySet().iterator();
		while (iter.hasNext()){
			Object targetElem = iter.next();
			//check if elem is of type sml:refType
			if (!refTypeElems.contains(targetElem)){
				boolean valid = false;
				//check inheritance tree
				Object parent = inheritance.get(targetElem);
				while (parent != null){
					if (refTypeElems.contains(parent)){
						valid = true;
						break;
					}
					parent = inheritance.get(parent);
					
				}
				if (!valid){
					validationLogger.reportError("Element "+targetElem+" defines target element attribute whose type or derived type is not sml:refType");
					//stop validating
					return false;
				}
			}
			
			//make sure the target value is a global type
			Object targetValue = targetElems.get(targetElem);
			if (!complexTypeElems.contains(targetValue)){
				validationLogger.reportError("Element "+targetElem+" defines target element \""+targetValue+"\" that is not defined");
				//stop validating
				return false;
			}
		}
		
		//make sure
		
		
		return true;
	}

	public String[] getScope()
	{
		// TODO Auto-generated method stub
		return null;
	}

	public void setScope(String[] scope)
	{
		// TODO Auto-generated method stub
		
	}

}
